#
# spec file for package framework_tool
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define reponame framework-system
%define completion_dir_bash %{_datadir}/bash-completion/completions
%define completion_dir_zsh %{_datadir}/zsh/functions/Completion
Name:           framework_tool
Version:        0.4.3
Release:        1.1
Summary:        Rust tools to interact with the Framework Computer systems
License:        BSD-3-Clause
URL:            https://github.com/FrameworkComputer/framework-system
Source0:        https://github.com/FrameworkComputer/framework-system/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
# PATCH-FIX-OPENSUSE make-reproducable.patch
Patch0:         make-reproducable.patch
BuildRequires:  cargo-packaging
BuildRequires:  pkg-config
BuildRequires:  systemd-devel
BuildRequires:  zsh
ExclusiveArch:  x86_64

%description
Rust tools to interact with the Framework Computer systems, especially with the built-in embedded controller

%prep
%autosetup -p1 -a1 -n %{reponame}-%{version}

%build
%cargo_build

%install
install -D -m 0755 target/release/%{name} %{buildroot}%{_bindir}/%{name}
install -D -m 0644 completions/bash/framework_tool %{buildroot}%{completion_dir_bash}/framework_tool.bash
install -D -m 0644 completions/zsh/_framework_tool %{buildroot}%{completion_dir_zsh}/framework_tool.zsh

%check
%cargo_test

%files
%license LICENSE.md
%doc README.md support-matrices.md EXAMPLES.md
%{_bindir}/%{name}
%{completion_dir_bash}/framework_tool.bash
%{completion_dir_zsh}/framework_tool.zsh

%changelog
* Tue Jun 10 2025 Nico Krapp <nico.krapp@suse.com>
- Update to 0.4.3
  * gh-actions: Split UEFI build into separate action by @JohnAZoidberg in #151
  * esrt: Add framework desktop GUID by @JohnAZoidberg in #152
  * MEC detection: Fail if permission denied by @JohnAZoidberg in #154
  * Add devenv.nix by @JohnAZoidberg in #155
  * esrt: fix ESRT GUID for EFI device by @aokblast in #156
  * --versions: Show any number of PD versions by @JohnAZoidberg in #157
  * Fix formatting by @JohnAZoidberg in #158
  * ec_binary: Make it less misleading if legacy cookie not found
    by @JohnAZoidberg in #159
  * EXAMPLES: Add intel core ultra by @JohnAZoidberg in #161
  * README: Explain how to install with winget by @JohnAZoidberg in #162
  * chromium_ec: Erase EC in sections by @JohnAZoidberg in #160
  * EXAMPLES: Document fingerprint reader brightness by @JohnAZoidberg in #164
  * Show ALS sensor on unknown systems by @JohnAZoidberg in #163
  * Add support for dynamic number of PDs by @JohnAZoidberg in #166
  * Add debug commands to disable/enable and reset PD controller
    by @JohnAZoidberg in #165
  * README: Add nix-shell by @JohnAZoidberg in #168
  * portio_mec: Don't print init by @JohnAZoidberg in #169
  * Correctly identify right and left PD controllers by @JohnAZoidberg in #170
  * framework_tool: Add copyright into .exe properties
    by @JohnAZoidberg in #172
  * Fix remap key docstring by @jodavaho in #173
  * fw16: add command to write and read expansion bay eeprom by @kiram9 in #171
  * Bump version to 0.4.3 by @JohnAZoidberg in #167
* Mon May 26 2025 Nico Krapp <nico.krapp@suse.com>
- Update to 0.4.2
  * --expansion-bay: Print PCIe config by @JohnAZoidberg in #138
  * --get-gpio: Return all GPIOs if no name was passed
    by @JohnAZoidberg in #142
  * --sensors: Get information about sensors by @JohnAZoidberg in #143
  * Add --ps2-enable to control ps2 emulation by @JohnAZoidberg in #139
  * Cleanup --versions command to hide unnecessary details
    by @JohnAZoidberg in #146
  * Allow keyboard remapping by @JohnAZoidberg in #145
  * Build Rufus compatible ISO by @JohnAZoidberg in #149
  * Allow installing with cargo install by @JohnAZoidberg in #147
  * Allow flashing EC RW region by @JohnAZoidberg in #150
* Thu May  8 2025 Nico Krapp <nico.krapp@suse.com>
- Update to 0.4.1
  * Fix charge limit based on battery charge by @JohnAZoidberg in #123
  * Split I2C tunneling out of ccgx module by @JohnAZoidberg in #112
  * chromium_ec: Use portio if /dev/cros_ec does not exist
    by @JohnAZoidberg in #124
  * chromioum_ec: Autodetect Microchip EC when using portio
    by @JohnAZoidberg in #125
  * --version: Add revision of mainboard by @JohnAZoidberg in #127
  * --inputdeck: Fix Chassis Closed status by @JohnAZoidberg in #130
  * Don't require PD config if platform isn't detected
    by @JohnAZoidberg in #129
  * Simplify features and detect based on OS by @JohnAZoidberg in #126
  * windows: Run --versions command if double-clicked
    by @JohnAZoidberg in #132
  * --thermal: Add Framework 12 charger IC temp and unknown sensors
    by @JohnAZoidberg in #135
  * windows: Fix --console follow by @JohnAZoidberg in #136
  * Bump version to 0.4.1 by @JohnAZoidberg in #133
  * More examples by @JohnAZoidberg in #137
* Fri May  2 2025 Nico Krapp <nico.krapp@suse.com>
- Update to 0.4.0
  * framework_uefi: Document how to build on Windows
    by @JohnAZoidberg in #102
  * Don't show retimer as unknown if none present
    by @JohnAZoidberg in #103
  * gh-actions: Disable FreeBSD builds by @JohnAZoidberg in #105
  * chromium_ec: Add adc_read by @JohnAZoidberg in #108
  * freebsd: Remove warning by @JohnAZoidberg in #110
  * chromium_ec: Fix reading EC console by @JohnAZoidberg in #106
  * Fix windows clippy lint by @JohnAZoidberg in #111
  * power: Detect number of fans and report all of them
    by @JohnAZoidberg in #113
  * Revert "gh-actions: Disable FreeBSD builds"
    by @JohnAZoidberg in #115
  * Allow custom fan speed control by @JohnAZoidberg in #114
  * Show firmware version of Framework 16 Inputmodules
    by @JohnAZoidberg in #104
  * Add more EXAMPLES by @JohnAZoidberg in #116
  * Add --expansion-bay command to print info by @JohnAZoidberg in #107
  * --input-deck: Print Framework12 and Framework 13 input deck status
    by @JohnAZoidberg in #109
  * touchscreen_win: Find the right path with hidapi
    by @JohnAZoidberg in #119
  * Chargerate by @JohnAZoidberg in #117
  * Improve commandline output by @JohnAZoidberg in #121
  * Get information from USI Stylus by @JohnAZoidberg in #118
  * Add command to set EC hibernation delay by @JohnAZoidberg in #122
  * Bump version to 0.4.0 by @JohnAZoidberg in #120
- add examples to documentation
* Mon Apr 28 2025 Nico Krapp <nico.krapp@suse.com>
- Update to 0.3.0
  * Add export and Debug deriving by @JohnAZoidberg in #78
  * Update dependencies by @JohnAZoidberg in #79
  * Add support for Framework 2nd Gen Event platforms
    by @JohnAZoidberg in #81
  * Add command to toggle tablet mode by @JohnAZoidberg in #82
  * fp-brightness: Add support for V1 host command
    by @JohnAZoidberg in #85
  * framework_lib: Add ultra-low powerbutton brightness
    by @JohnAZoidberg in #83
  * Add accelerometer support by @JohnAZoidberg in #86
  * chromium: Add device_complete to diags by @JohnAZoidberg in #87
  * Add support for RGB command by @JohnAZoidberg in #84
  * freebsd: Build with latest stable on gh actions
    by @JohnAZoidberg in #89
  * camera: Print firmware version of camera by @JohnAZoidberg in #88
  * camera: Don't crash if something's wrong by @JohnAZoidberg in #93
  * touchpad: Show IC type and firmware version by @JohnAZoidberg in #94
  * Fix H2O capsule analysis by @JohnAZoidberg in #92
  * windows: Upload release binary by @JohnAZoidberg in #99
  * windows: Don't panic if driver not installed
    by @JohnAZoidberg in #100
  * framework12: Support reading touchpad version
    by @JohnAZoidberg in #97
  * touchscreen: Dump firmware version and protocol
    by @JohnAZoidberg in #90
  * add commands to read/write gpu serial by @kiram9 in #98
  * Add completions for ZSH and Bash by @bsdlme in #96
* Wed Apr 16 2025 Nico Krapp <nico.krapp@suse.com>
- add make-reproducable.patch to force newer versions of
  dependencies to make package reproducable
* Wed Feb 26 2025 Nico Krapp <nico.krapp@suse.com>
- Update to 0.2.1
  * ccgx: Format PD version as decimal on 11th Gen by @JohnAZoidberg in #75
  * Bump to v0.2.1 by @JohnAZoidberg in #77
- Update to 0.2.0
  * Merge pull request #67 from FrameworkComputer/prep-v0.2.0
  * Release v0.2.0
* Wed Nov 20 2024 Nico Krapp <nico.krapp@suse.com>
- initial version 0.1.0
